==> 0.2.0.tar.gz: lib/src/jaguar_mux.dart <==
library jaguar_mux.jaguar_mux;

import 'package:jaguar/jaguar.dart';

import 'mux/mux.dart';

part 'route.dart';

class MuxBuilder {
  final List<Route> _routes = [];

  List<Route> get routes => new List.unmodifiable(_routes);

  final List<RouteWrapper> _wrappers = [];

  List<RouteWrapper> get wrappers => new List.unmodifiable(_wrappers);

  bool _wrapsFinalized = false;

  MuxBuilder wrap(RouteWrapper interceptor) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (interceptor == null) return this;
    _wrappers.add(interceptor);
    return this;
  }

  Route route(String path, Function handler,
      {Map<String, String> pathRegEx,
      List<String> methods: const <String>['GET', 'PUT', 'POST', 'DELETE']}) {
    Route route =
        new Route(path, handler, pathRegEx: pathRegEx, methods: methods);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route get(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Get(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route post(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Post(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route put(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Put(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route delete(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Delete(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Group group({String pathPrefix: ''}) {
    return new Group(this, pathPrefix: pathPrefix);
  }

  Route addRoute(Route route) {
    _routes.add(route);
    route._wrapAllAtBeginning(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Mux build() => new Mux.build(this);
}

class Group {
  final MuxBuilder _muxBuilder;

  final String pathPrefix;

  final List<RouteWrapper> _wrappers = [];

  List<RouteWrapper> get wrappers => new List.unmodifiable(_wrappers);

  bool _wrapsFinalized = false;

  Group wrap(RouteWrapper interceptor) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (interceptor == null) return this;
    _wrappers.add(interceptor);
    return this;
  }

  Group(this._muxBuilder, {String pathPrefix: ''})
      : pathPrefix = pathPrefix ?? '';

  Route route(String path, Function handler,
      {Map<String, String> pathRegEx,
      List<String> methods: const <String>['GET', 'PUT', 'POST', 'DELETE']}) {
    Route route = new Route(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx, methods: methods);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route get(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Get(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route post(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Post(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route put(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Put(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route delete(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Delete(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route addRoute(Route route) {
    route._wrapAllAtBeginning(_wrappers);
    _muxBuilder.addRoute(route);
    _wrapsFinalized = true;
    return route;
  }

  Group group({String pathPrefix: ''}) {
    return new Group(_muxBuilder,
        pathPrefix: this.pathPrefix + (pathPrefix ?? ''));
  }
}

==> 0.2.2.tar.gz: lib/src/jaguar_mux.dart <==
library jaguar_mux.jaguar_mux;

import 'package:jaguar/jaguar.dart';

import 'mux/mux.dart';

part 'group.dart';
part 'route.dart';

class MuxBuilder {
  final List<Route> _routes = [];

  List<Route> get routes => new List.unmodifiable(_routes);

  final List<RouteWrapper> _wrappers = [];

  List<RouteWrapper> get wrappers => new List.unmodifiable(_wrappers);

  bool _wrapsFinalized = false;

  MuxBuilder wrap(RouteWrapper interceptor) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (interceptor == null) return this;
    _wrappers.add(interceptor);
    return this;
  }

  Route route(String path, Function handler,
      {Map<String, String> pathRegEx,
      List<String> methods: const <String>['GET', 'PUT', 'POST', 'DELETE']}) {
    Route route =
        new Route(path, handler, pathRegEx: pathRegEx, methods: methods);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route get(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Get(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route post(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Post(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route put(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Put(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Route delete(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Delete(path, handler, pathRegEx: pathRegEx);
    route.wrapAll(_wrappers);
    _routes.add(route);
    _wrapsFinalized = true;
    return route;
  }

  Group group([String path = '']) {
    return new Group(this, path: path);
  }

  Route addRoute(Route route) {
    _routes.add(route);
    route._wrapAllAtBeginning(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Mux build() => new Mux.build(this);
}
